@@ -554,8 +554,14 @@ HTS_STATIC int strcmpnocase(char* a,char* b) {
 #else
 #define OPT_MMS(a) (0)
 #endif
-#define is_hypertext_mime__(a) \
+
+#define is_html_mime_type(a) \
   ( (strfield2((a),"text/html")!=0)\
+  || (strfield2((a),"application/xhtml+xml")!=0) \
+  )
+#define is_hypertext_mime__(a) \
+  ( \
+  is_html_mime_type(a)\
   || (strfield2((a),"application/x-javascript")!=0) \
   || (strfield2((a),"text/css")!=0) \
   /*|| (strfield2((a),"text/vnd.wap.wml")!=0)*/ \
@@ -572,7 +578,6 @@ HTS_STATIC int strcmpnocase(char* a,char* b) {
      || OPT_MMS(a) \
   )
 
-
 /* Library internal definictions */
 #ifdef HTS_INTERNAL_BYTECODE
 
